import 'package:flutter/material.dart';
import 'package:hub/backend/api_requests/api_manager.dart';
import 'package:hub/components/molecular_components/message_opt_modal/opt_modal_widget.dart';
import 'package:hub/flutter_flow/flutter_flow_model.dart';
import 'package:hub/flutter_flow/request_manager.dart';
import 'package:hub/pages/acess_history_page/acess_history_page_widget.dart';
import 'package:hub/shared/helpers/db_helper.dart';

class AcessHistoryPageModel extends FlutterFlowModel<AccessHistoryScreen> {
  final DatabaseHelper db = DatabaseHelper();
  late final String devUUID;
  late final String userUUID;
  late final String cliUUID;

  final unfocusNode = FocusNode();
  final _accessHistoryManager = FutureRequestManager<ApiCallResponse>();
  Future<ApiCallResponse> accessHistory({
    String? uniqueQueryKey,
    bool? overrideCache,
    required Future<ApiCallResponse> Function() requestFn,
  }) =>
      _accessHistoryManager.performRequest(
        uniqueQueryKey: uniqueQueryKey,
        overrideCache: overrideCache,
        requestFn: requestFn,
      );
  void clearAccessHistoryCache() => _accessHistoryManager.clear();
  void clearAccessHistoryCacheKey(String? uniqueKey) =>
      _accessHistoryManager.clearRequest(uniqueKey);

  @override
  void initState(BuildContext context) {
    initDatabase();
  }

  Future<void> initDatabase() async {
    devUUID = await db
        .get(key: 'devUUID', field: 'value')
        .then((value) => value.toString());
    userUUID = await db
        .get(key: 'userUUID', field: 'value')
        .then((value) => value.toString());
    cliUUID = await db
        .get(key: 'cliUUID', field: 'value')
        .then((value) => value.toString());
  }

  @override
  void dispose() {
    unfocusNode.dispose();

    clearAccessHistoryCache();
  }

  Future toggleOptionsAction(BuildContext context) async {
    await showModalBottomSheet(
      isScrollControlled: true,
      backgroundColor: Colors.transparent,
      useSafeArea: true,
      context: context,
      builder: (context) {
        return GestureDetector(
          onTap: () => unfocusNode.canRequestFocus
              ? FocusScope.of(context).requestFocus(unfocusNode)
              : FocusScope.of(context).unfocus(),
          child: Padding(
            padding: MediaQuery.viewInsetsOf(context),
            child: const OptModalWidget(),
          ),
        );
      },
    );
  }
}
