import 'package:flutter/material.dart';
import 'package:hub/app_state.dart';
import 'package:hub/components/organism_components/local_profile_component/local_profile_component_model.dart';
import 'package:hub/components/organism_components/menu_component/menu_component_model.dart';
import 'package:hub/components/organism_components/message_well_component/message_well_component_model.dart';
import 'package:hub/flutter_flow/flutter_flow_model.dart';
import 'package:hub/pages/home_page/home_page_widget.dart';
import 'package:hub/shared/helpers/db_helper.dart';

class HomePageModel extends FlutterFlowModel<HomePageWidget> {
  bool isGrid = false;
  final DatabaseHelper db = DatabaseHelper();
  late final String devUUID;
  late final String cliUUID;
  late final String userUUID;
  late final String userName;
  late final String userEmail;

  final unfocusNode = FocusNode();
  FocusNode? textFieldFocusNode;
  TextEditingController? textController;
  String? Function(BuildContext, String?)? textControllerValidator;
  late LocalProfileComponentModel localComponentModel;
  late MenuComponentModel menuComponentModel;
  late MessageWellComponentModel messageWellComponentModel;

  Future<void> _initVariable() async {
    devUUID = await db
        .get(key: 'devUUID', field: 'value')
        .then((value) => value.toString());
    cliUUID = await db
        .get(key: 'cliUUID', field: 'value')
        .then((value) => value.toString());
    userUUID = await db
        .get(key: 'userUUID', field: 'value')
        .then((value) => value.toString());
    userName = await db
        .get(key: 'userName', field: 'value')
        .then((value) => value.toString());
    userEmail = AppState().email;
  }

  @override
  void initState(BuildContext context) {
    _initVariable();
    localComponentModel =
        createModel(context, () => LocalProfileComponentModel());
    menuComponentModel = createModel(context, () => MenuComponentModel());
    messageWellComponentModel =
        createModel(context, () => MessageWellComponentModel());
  }

  @override
  void dispose() {
    unfocusNode.dispose();
    textFieldFocusNode?.dispose();
    textController?.dispose();

    localComponentModel.dispose();
    menuComponentModel.dispose();
    messageWellComponentModel.dispose();
  }
}
